Don't retransmit interests within 100ms
diff --git a/model/ccnx-pit-entry.cc b/model/ccnx-pit-entry.cc
index bcd384d..9c8c389 100644
--- a/model/ccnx-pit-entry.cc
+++ b/model/ccnx-pit-entry.cc
@@ -153,12 +153,12 @@
CcnxPitEntry::IncreaseAllowedRetxCount ()
{
NS_LOG_ERROR (this);
- // if (Simulator::Now () - m_lastRetransmission >= MilliSeconds (10))
+ if (Simulator::Now () - m_lastRetransmission >= MilliSeconds (100))
{
// cheat:
// don't allow retransmission faster than every 10ms
m_maxRetxCount++;
- // m_lastRetransmission = Simulator::Now ();
+ m_lastRetransmission = Simulator::Now ();
}
}
@@ -153,12 +153,12 @@
{
// cheat:
- // don't allow retransmission faster than every 10ms
+ // don't allow retransmission faster than every 100ms
m_maxRetxCount++;